@@ -2,6 +2,7 @@
 ###
 ### Copyright 1997-2003  Jose C. Pinheiro,
 ###                      Douglas M. Bates <bates@stat.wisc.edu>
+# Copyright 2006-2014 The R Core team
 #
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -84,18 +85,7 @@ nlsList.formula <-
     FUN <- eval(model[[3]][[1]])
     if (is.function(FUN) && class(FUN) != "selfStart" &&
         !is.null(attr(FUN, "initial"))) {
-      stop(paste("old-style self-starting model functions\n",
-                 "are no longer supported.\n",
-                 "New selfStart functions are available.\n",
-                 "Use\n",
-                 "  SSfpl instead of fpl,\n",
-                 "  SSfol instead of first.order.log,\n",
-                 "  SSbiexp instead of biexp,\n",
-                 "  SSlogis instead of logistic.\n",
-                 "If writing your own selfStart model, see\n",
-                 "  \"help(selfStart)\"\n",
-                 "for the new form of the \"initial\" attribute.", sep="" ),
-           domain = NA)
+      stop("old-style self-starting model functions\nare no longer supported.\nNew selfStart functions are available.\nUse\n  SSfpl instead of fpl,\n  SSfol instead of first.order.log,\n  SSbiexp instead of biexp,\n  SSlogis instead of logistic.\nIf writing your own selfStart model, see\n  \"help(selfStart)\"\nfor the new form of the \"initial\" attribute.")
     }
   }
 
